WARNING - OLD ARCHIVES

This is an archived copy of the Xen.org mailing list, which we have preserved to ensure that existing links to archives are not broken. The live archive, which contains the latest emails, can be found at http://lists.xen.org/
   
 
 
Xen 
 
Home Products Support Community News
 
   
 

xen-changelog

[Xen-changelog] [xen-unstable] Rename Console.uri to location. Xend alre

To: xen-changelog@xxxxxxxxxxxxxxxxxxx
Subject: [Xen-changelog] [xen-unstable] Rename Console.uri to location. Xend already uses the latter.
From: Xen patchbot-unstable <patchbot-unstable@xxxxxxxxxxxxxxxxxxx>
Date: Tue, 20 Feb 2007 19:30:14 -0800
Delivery-date: Tue, 20 Feb 2007 19:30:14 -0800
Envelope-to: www-data@xxxxxxxxxxxxxxxxxx
List-help: <mailto:xen-changelog-request@lists.xensource.com?subject=help>
List-id: BK change log <xen-changelog.lists.xensource.com>
List-post: <mailto:xen-changelog@lists.xensource.com>
List-subscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=subscribe>
List-unsubscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=unsubscribe>
Reply-to: xen-devel@xxxxxxxxxxxxxxxxxxx
Sender: xen-changelog-bounces@xxxxxxxxxxxxxxxxxxx
# HG changeset patch
# User Ewan Mellor <ewan@xxxxxxxxxxxxx>
# Date 1171999408 0
# Node ID be35eed950da0f39d3d41f738f340707e01c4cbd
# Parent  8773b1a38c83667b000f496eb0906c3284087345
Rename Console.uri to location.  Xend already uses the latter.

Signed-off-by: Ewan Mellor <ewan@xxxxxxxxxxxxx>
---
 docs/xen-api/xenapi-datamodel.tex  |   16 ++++++++--------
 tools/libxen/include/xen_console.h |   16 ++++++++--------
 tools/libxen/src/xen_console.c     |   32 ++++++++++++++++----------------
 3 files changed, 32 insertions(+), 32 deletions(-)

diff -r 8773b1a38c83 -r be35eed950da docs/xen-api/xenapi-datamodel.tex
--- a/docs/xen-api/xenapi-datamodel.tex Tue Feb 20 16:30:24 2007 +0000
+++ b/docs/xen-api/xenapi-datamodel.tex Tue Feb 20 19:23:28 2007 +0000
@@ -10885,7 +10885,7 @@ Quals & Field & Type & Description \\
 \hline
 $\mathit{RO}_\mathit{run}$ &  {\tt uuid} & string & unique identifier/object 
reference \\
 $\mathit{RO}_\mathit{run}$ &  {\tt protocol} & console\_protocol & the 
protocol used by this console \\
-$\mathit{RO}_\mathit{run}$ &  {\tt uri} & string & URI for the console service 
\\
+$\mathit{RO}_\mathit{run}$ &  {\tt location} & string & URI for the console 
service \\
 $\mathit{RO}_\mathit{run}$ &  {\tt VM} & VM ref & VM to which this console is 
attached \\
 \hline
 \end{longtable}
@@ -10954,13 +10954,13 @@ value of the field
 \vspace{0.3cm}
 \vspace{0.3cm}
 \vspace{0.3cm}
-\subsubsection{RPC name:~get\_uri}
-
-{\bf Overview:} 
-Get the uri field of the given console.
-
- \noindent {\bf Signature:} 
-\begin{verbatim} string get_uri (session_id s, console ref self)\end{verbatim}
+\subsubsection{RPC name:~get\_location}
+
+{\bf Overview:} 
+Get the location field of the given console.
+
+ \noindent {\bf Signature:} 
+\begin{verbatim} string get_location (session_id s, console ref 
self)\end{verbatim}
 
 
 \noindent{\bf Arguments:}
diff -r 8773b1a38c83 -r be35eed950da tools/libxen/src/xen_console.c
--- a/tools/libxen/src/xen_console.c    Tue Feb 20 16:30:24 2007 +0000
+++ b/tools/libxen/src/xen_console.c    Tue Feb 20 19:23:28 2007 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006, XenSource Inc.
+ * Copyright (c) 2006-2007, XenSource Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,9 +44,9 @@ static const struct_member xen_console_r
         { .key = "protocol",
           .type = &xen_console_protocol_abstract_type_,
           .offset = offsetof(xen_console_record, protocol) },
-        { .key = "uri",
+        { .key = "location",
           .type = &abstract_type_string,
-          .offset = offsetof(xen_console_record, uri) },
+          .offset = offsetof(xen_console_record, location) },
         { .key = "VM",
           .type = &abstract_type_ref,
           .offset = offsetof(xen_console_record, vm) }
@@ -71,7 +71,7 @@ xen_console_record_free(xen_console_reco
     }
     free(record->handle);
     free(record->uuid);
-    free(record->uri);
+    free(record->location);
     xen_vm_record_opt_free(record->vm);
     free(record);
 }
@@ -164,18 +164,18 @@ xen_console_get_protocol(xen_session *se
 
 
 bool
-xen_console_get_uri(xen_session *session, char **result, xen_console console)
-{
-    abstract_value param_values[] =
-        {
-            { .type = &abstract_type_string,
-              .u.string_val = console }
-        };
-
-    abstract_type result_type = abstract_type_string;
-
-    *result = NULL;
-    XEN_CALL_("console.get_uri");
+xen_console_get_location(xen_session *session, char **result, xen_console 
console)
+{
+    abstract_value param_values[] =
+        {
+            { .type = &abstract_type_string,
+              .u.string_val = console }
+        };
+
+    abstract_type result_type = abstract_type_string;
+
+    *result = NULL;
+    XEN_CALL_("console.get_location");
     return session->ok;
 }
 

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog

<Prev in Thread] Current Thread [Next in Thread>
  • [Xen-changelog] [xen-unstable] Rename Console.uri to location. Xend already uses the latter., Xen patchbot-unstable <=
diff -r 8773b1a38c83 -r be35eed950da tools/libxen/include/xen_console.h
--- a/tools/libxen/include/xen_console.h        Tue Feb 20 16:30:24 2007 +0000
+++ b/tools/libxen/include/xen_console.h        Tue Feb 20 19:23:28 2007 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006, XenSource Inc.
+ * Copyright (c) 2006-2007, XenSource Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,8 +26,8 @@
 
 
 /*
- * The console class. 
- *  
+ * The console class.
+ * 
  * A console.
  */
 
@@ -65,7 +65,7 @@ typedef struct xen_console_record
     xen_console handle;
     char *uuid;
     enum xen_console_protocol protocol;
-    char *uri;
+    char *location;
     struct xen_vm_record_opt *vm;
 } xen_console_record;
 
@@ -191,10 +191,10 @@ xen_console_get_protocol(xen_session *se
 
 
 /**
- * Get the uri field of the given console.
- */
-extern bool
-xen_console_get_uri(xen_session *session, char **result, xen_console console);
+ * Get the location field of the given console.
+ */
+extern bool
+xen_console_get_location(xen_session *session, char **result, xen_console 
console);
 
 
 /**